@@ -5,11 +5,11 @@ import numbers
 import pytest
 
 import mbedtls
-import mbedtls.hash as _hash
+from mbedtls import hashlib
 from mbedtls.exceptions import *
 from mbedtls.mpi import MPI
-from mbedtls.pk import _type_from_name, _get_md_alg, ECPoint
 from mbedtls.pk import *
+from mbedtls.pk import ECPoint, _get_md_alg, _type_from_name
 
 try:
     long
@@ -26,12 +26,13 @@ def test_get_supported_ciphers():
 
 
 @pytest.mark.parametrize(
-    "md_algorithm", [vars(_hash)[name] for name in _hash.algorithms_available]
+    "md_algorithm",
+    [vars(hashlib)[name] for name in hashlib.algorithms_available],
 )
 def test_digestmod_from_ctor(md_algorithm):
     assert callable(md_algorithm)
     algorithm = _get_md_alg(md_algorithm)
-    assert isinstance(algorithm(), _hash.Hash)
+    assert isinstance(algorithm(), hashlib.Hash)
 
 
 class TestECPoint:
@@ -165,7 +166,7 @@ class _TestCipherBase:
 
     @pytest.mark.parametrize(
         "digestmod",
-        [_get_md_alg(name) for name in _hash.algorithms_guaranteed],
+        [_get_md_alg(name) for name in hashlib.algorithms_guaranteed],
         ids=lambda dm: dm().name,
     )
     def test_sign_without_key_returns_none(self, cipher, digestmod, randbytes):
@@ -175,7 +176,7 @@ class _TestCipherBase:
     @pytest.mark.usefixtures("key")
     @pytest.mark.parametrize(
         "digestmod",
-        [_get_md_alg(name) for name in _hash.algorithms_guaranteed],
+        [_get_md_alg(name) for name in hashlib.algorithms_guaranteed],
         ids=lambda dm: dm().name,
     )
     def test_sign_verify(self, cipher, digestmod, randbytes):
